from PIL import Image
import os
import glob

# Функция для сглаживания горизонтальных линий
def smooth_horizontal_lines(image, min_length=50, gap_tolerance=0, line_thickness=2):
    pixels = image.load()
    width, height = image.size
    new_image = image.copy()
    new_pixels = new_image.load()

    for y in range(height):
        x_start = None
        gap_size = 0
        for x in range(width):
            if pixels[x, y] == 0:  # Не белый пиксель
                if x_start is None:
                    x_start = x  # начало черного сегмента
                gap_size = 0  # сброс разрыва
            else:
                if x_start is not None:
                    gap_size += 1
                    if gap_size > gap_tolerance:
                        length = x - x_start - gap_size
                        if length >= min_length:
                            # Обрабатываем линию как целое, расширяя её на одинаковую толщину
                            for yy in range(max(0, y - line_thickness // 2), min(height, y + line_thickness // 2 + 1)):
                                for xx in range(x_start, x - gap_size):
                                    new_pixels[xx, yy] = 0  # Устанавливаем черный пиксель
                        x_start = None
                        gap_size = 0

        # Проверка последнего сегмента
        if x_start is not None and (width - x_start - gap_size) >= min_length:
            for yy in range(max(0, y - line_thickness // 2), min(height, y + line_thickness // 2 + 1)):
                for xx in range(x_start, width - gap_size):
                    new_pixels[xx, yy] = 0

    return new_image

# Функция для сглаживания вертикальных линий
def smooth_vertical_lines(image, min_length=50, gap_tolerance=0, line_thickness=2):
    pixels = image.load()
    width, height = image.size
    new_image = image.copy()
    new_pixels = new_image.load()

    for x in range(width):
        y_start = None
        gap_size = 0
        for y in range(height):
            if pixels[x, y] == 0:  # Не белый пиксель
                if y_start is None:
                    y_start = y  # начало черного сегмента
            
            else:
                if y_start is not None:
                    gap_size += 1
                    if gap_size > gap_tolerance:
                        length = y - y_start - gap_size
                        if length >= min_length:
                            # Обрабатываем линию как целое, расширяя её на одинаковую толщину
                            for xx in range(max(0, x - line_thickness // 2), min(width, x + line_thickness // 2 + 1)):
                                for yy in range(y_start, y - gap_size):
                                    new_pixels[xx, yy] = 0  # Устанавливаем черный пиксель
                        y_start = None
                        gap_size = 0

        # Проверка последнего сегмента
        if y_start is not None and (height - y_start - gap_size) >= min_length:
            for xx in range(max(0, x - line_thickness // 2), min(width, x + line_thickness // 2 + 1)):
                for yy in range(y_start, height - gap_size):
                    new_pixels[xx, yy] = 0

    return new_image



# Функция для обработки одиночного изображения
def process_image(image):
    # Последовательная обработка изображения
    new_image = smooth_horizontal_lines(image, min_length=600, gap_tolerance=10, line_thickness=6)
    new_image = smooth_vertical_lines(new_image, min_length=100, gap_tolerance=8, line_thickness=6)
    return new_image


# Функция для обработки всех изображений в папке
def process_folder(input_folder, output_folder):
    if not os.path.exists(output_folder):
        os.makedirs(output_folder)
        
    bmp_files = glob.glob(os.path.join(input_folder, "*.bmp"))
    for file_path in bmp_files:
        print(f"Processing file: {file_path}")
        image = Image.open(file_path).convert('L')
        
        # Обработка изображения
        processed_image = process_image(image)
        
        # Сохранение результата
        output_file = os.path.join(output_folder, os.path.basename(file_path))
        processed_image.save(output_file, dpi=(600, 600))
        
    print("All files processed.")

# Пример вызова функции для обработки всех изображений в папке
input_folder = r'C:\Users\1\Desktop\python'
output_folder = r'C:\Users\1\Desktop\python\2'
process_folder(input_folder, output_folder)
